@@ -21,6 +21,11 @@ import time
 import warnings
 from typing import Any, Dict, Optional, Union
 
+try:
+    from importlib import metadata
+except ImportError:
+    import importlib_metadata as metadata  # type: ignore[import,no-redef]
+
 import urllib3
 from urllib3.exceptions import ConnectTimeoutError, NewConnectionError, ReadTimeoutError
 from urllib3.util.retry import Retry
@@ -47,7 +52,7 @@ except (ImportError, AttributeError):
 class Urllib3HttpNode(BaseNode):
     """Default synchronous node class using the ``urllib3`` library via HTTP"""
 
-    _CLIENT_META_HTTP_CLIENT = ("ur", client_meta_version(urllib3.__version__))
+    _CLIENT_META_HTTP_CLIENT = ("ur", client_meta_version(metadata.version("urllib3")))
 
     def __init__(self, config: NodeConfig):
         super().__init__(config)
@@ -70,7 +75,6 @@ class Urllib3HttpNode(BaseNode):
             # about the fingerprint of the certificates, not whether they form
             # a verified chain to a trust anchor.
             elif config.ssl_assert_fingerprint:
-
                 # Manually disable these in the right order on the SSLContext
                 # so urllib3 won't think we want conflicting things.
                 ssl_context.check_hostname = False
@@ -118,7 +122,7 @@ class Urllib3HttpNode(BaseNode):
                             category=SecurityWarning,
                         )
                     else:
-                        urllib3.disable_warnings()  # type: ignore[no-untyped-call]
+                        urllib3.disable_warnings()
 
         self.pool = pool_class(
             config.host,
@@ -137,7 +141,6 @@ class Urllib3HttpNode(BaseNode):
         headers: Optional[HttpHeaders] = None,
         request_timeout: Union[DefaultType, Optional[float]] = DEFAULT,
     ) -> NodeApiResponse:
-
         if self.path_prefix:
             target = f"{self.path_prefix}{target}"
 
@@ -161,13 +164,13 @@ class Urllib3HttpNode(BaseNode):
             else:
                 body_to_send = None
 
-            response = self.pool.urlopen(  # type: ignore[no-untyped-call]
+            response = self.pool.urlopen(
                 method,
                 target,
                 body=body_to_send,
                 retries=Retry(False),
                 headers=request_headers,
-                **kw,
+                **kw,  # type: ignore[arg-type]
             )
             response_headers = HttpHeaders(response.headers)
             data = response.data
@@ -222,4 +225,4 @@ class Urllib3HttpNode(BaseNode):
         """
         Explicitly closes connection
         """
-        self.pool.close()  # type: ignore[no-untyped-call]
+        self.pool.close()
